s_plot_settings_begin_end: Plot settings for all plots

Description Usage Arguments Details Value

Description

Settings:

Usage

1
2
3
s_plot_settings_begin_end(filename_prefix = "Prefix",
  plot_filename = "default_filename", plot_mode = "settings",
  plot_format = 1)

Arguments

filename_prefix

xxxPARAMxxx

plot_filename

xxxPARAMxxx

plot_mode

xxxPARAMxxx

plot_format

xxxPARAMxxx

Details

filenames

devices settings

par settings

Begin:

to interactive display

png is default output since quick display on web and used to convert to other raster formats

ps

pdf

bmp

jpeg

tiff

par settings

End:

Value

NULL xxxRETURNxxx


erikerhardt/isogasex documentation built on July 16, 2019, 5:25 a.m.