Description Usage Arguments Details Value
Settings:
1 2 3 | s_plot_settings_begin_end(filename_prefix = "Prefix",
plot_filename = "default_filename", plot_mode = "settings",
plot_format = 1)
|
filename_prefix |
xxxPARAMxxx |
plot_filename |
xxxPARAMxxx |
plot_mode |
xxxPARAMxxx |
plot_format |
xxxPARAMxxx |
filenames
devices settings
par settings
Begin:
to interactive display
png is default output since quick display on web and used to convert to other raster formats
ps
bmp
jpeg
tiff
par settings
End:
NULL xxxRETURNxxx
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.